summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_maintenance.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2017-01-07 17:02:29 +0100
committerHolger Levsen <holger@layer-acht.org>2017-01-07 17:02:29 +0100
commitca27265fef4fb6599ba5f95af3cd453acb868213 (patch)
tree9a8e7fc159a72243adcb43c3467564cefd965524 /bin/reproducible_maintenance.sh
parent3fa5b6c2e7e810fae739141bed67e93b76bda410 (diff)
downloadjenkins.debian.net-ca27265fef4fb6599ba5f95af3cd453acb868213.tar.xz
reproducible Debian: check for /(run|dev)/shm
Signed-off-by: Holger Levsen <holger@layer-acht.org>
Diffstat (limited to 'bin/reproducible_maintenance.sh')
-rwxr-xr-xbin/reproducible_maintenance.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/reproducible_maintenance.sh b/bin/reproducible_maintenance.sh
index 58f1df39..f18ab11d 100755
--- a/bin/reproducible_maintenance.sh
+++ b/bin/reproducible_maintenance.sh
@@ -57,11 +57,11 @@ if [ $? -ne 0 ] ; then
irc_message debian-reproducible "Proxy is down for $HOSTNAME, please tell the jenkins admins to fix this. (sudo service squid3 restart)"
exit 1
fi
-# check for /dev/shm being mounted
-echo "$(date -u) - testing whether /dev/shm is mounted..."
-mount | grep -q "^tmpfs on /dev/shm"
+# check for /(run|dev)/shm being mounted
+echo "$(date -u) - testing whether /(run|dev)/shm is mounted..."
+mount | egrep -q "^tmpfs on /(run|dev)/shm"
if [ $? -ne 0 ] ; then
- irc_message debian-reproducible "/dev/shm is not mounted correctly on $HOSTNAME, please tell the jenkins admins to fix this. (by adding 'none /dev/shm tmpfs rw,nosuid,nodev,noexec 0 0' to /etc/fstab"
+ irc_message debian-reproducible "/(run|dev)/shm is not mounted correctly on $HOSTNAME, please tell the jenkins admins to fix this. (by adding 'none /dev/shm tmpfs rw,nosuid,nodev,noexec 0 0' to /etc/fstab"
exit 1
fi